"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEngineContext = void 0;
const react_1 = require("react");
const context_1 = require("../component/context");
/**
 * A hook to access the value of the `EngineContext`. This is a low-level hook that you should
 * usually not need to call directly.
 *
 * @returns {EngineContext} the value of the `EngineContext`
 *
 * @example
 * export const ExampleComponent = () => {
 *   const engine = useEngineContext();
 *   return <div>{engine.getDataFile()}</div>;
 * };
 */
exports.useEngineContext = (hookName = 'hook') => {
    const engineValue = react_1.useContext(context_1.EngineContext);
    if (process.env.NODE_ENV !== 'production' && !engineValue) {
        throw new Error(`could not find Context Engine; please ensure this ${hookName} is wrapped in a <Provider>`);
    }
    return engineValue;
};
//# sourceMappingURL=use-engine-context.js.map