import { MetaData } from '@context-experiments/core';
export declare type Feature = [boolean, Record<string, unknown>, MetaData];
/**
 * A hook to access the state of a feature.
 *
 * This hook takes an optional `callerId` as the second parameter. The `callerId` improves the reliability
 * of eventing data by allowing the Decision Engine to identify the calling React Component through
 * the session's duration, thereby limiting duplicate eventing. The Engine considers all calls with
 * the same `callerId` to be the same Component; when rendering multiple instances of the same Component,
 * it can be advantageous to pass a unique `callerId`, allowing the Engine to track each Component
 * individually.
 *
 * @param {string} humanReadableId the human readable identifier of the `Feature`
 * @param {string=} callerId an identifier of the rendering React Component
 *
 * @returns {Feature} the `Feature` corresponding to the passed `featureReadableId`. If no feature exists
 * with the passed `featureReadableId` then an `InactiveFeature` is returned.
 *
 * @example
 * export const ExampleComponent = () => {
 *   const [isMyFeatureEnabled, { myFeatureVariable }, metaData] = useFeature(
 *     'my-feature.H291fd',
 *     'ExampleComponent',
 *   );
 *   return <div>{isMyFeatureEnabled && <span>{myFeatureVariable}</span>}</div>;
 * };
 */
export declare const useFeature: (featureReadableId: string, callerId?: string | undefined) => Feature;
//# sourceMappingURL=use-feature.d.ts.map