"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useIsomorphicLayoutEffect = void 0;
const react_1 = require("react");
/**
 * React currently throws a warning when using useLayoutEffect on the server. To get around it, we
 * can conditionally useEffect on the server (no-op) and useLayoutEffect in the browser. We need
 * useLayoutEffect to ensure ensure the engine subscription is created synchronously, otherwise
 * an engine update may occur before the subscription is created and an inconsistent state may be
 * observed.
 */
exports.useIsomorphicLayoutEffect = typeof window !== 'undefined' &&
    typeof window.document !== 'undefined' &&
    typeof window.document.createElement !== 'undefined'
    ? react_1.useLayoutEffect
    : react_1.useEffect;
//# sourceMappingURL=use-isomorphic-layout-effect.js.map