"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRevision = void 0;
const react_1 = require("react");
const use_engine_context_1 = require("./use-engine-context");
/**
 * A hook to access the revision.
 *
 * @returns {string} the revision of the current data file, or undefined if there is no active data
 * file.
 *
 * @example
 * export const ExampleComponent = () => {
 *   const revision = useRevision();
 *   return <div>{revision}</div>;
 * };
 */
exports.useRevision = () => {
    const engine = use_engine_context_1.useEngineContext('useRevision');
    return react_1.useMemo(() => engine.getRevision(), [engine]);
};
//# sourceMappingURL=use-revision.js.map