"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useStatus = void 0;
const react_1 = require("react");
const use_engine_context_1 = require("./use-engine-context");
/**
 * A hook to access the status of the Decision Engine.
 *
 * @returns {EngineStatus} the current status of the Decision Engine.
 *
 * @example
 * export const ExampleComponent = () => {
 *   const {
 *     activeExperiment,
 *     activeVariant,
 *     isDataFileAvailable,
 *     isDecisionMade,
 *     isDeviceIdentified,
 *   } = useStatus();
 *   return (
 *     <ul>
 *       <li>{activeExperiment}</li>
 *       <li>{activeVariant}</li>
 *       <li>{isDataFileAvailable}</li>
 *       <li>{isDecisionMade}</li>
 *       <li>{isDeviceIdentified}</li>
 *     </ul>
 *   );
 * };
 */
exports.useStatus = () => {
    const engine = use_engine_context_1.useEngineContext('useStatus');
    return react_1.useMemo(() => engine.getStatus(), [engine]);
};
//# sourceMappingURL=use-status.js.map