/**
 * A hook to access the Decision Engine setTargeting function.
 *
 * Calling `setTargeting` will **always** trigger the Decision Engine to recalculate all targeting decisions,
 * which triggers a re-render of all consumers. It is recommended that you wrap the invocation of `setTargeting`
 * within a `useEffect` and carefully consider how often 'setTargeting' is invoked.
 *
 * @returns {function} the Decision Engine's `setTargeting` function
 *
 * @example
 * export const ExampleComponent = ({ targetingValue }) => {
 *   const setTargeting = useTargeting();
 *   useEffect(() => {
 *     setTargeting({ targetingKey: targetingValue });
 *   }, [targetingValue, setTargeting]);
 *   return null;
 * };
 */
export declare const useTargeting: () => (targeting: Record<string, any>) => void;
//# sourceMappingURL=use-targeting.d.ts.map