"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTargeting = void 0;
const use_engine_context_1 = require("./use-engine-context");
/**
 * A hook to access the Decision Engine setTargeting function.
 *
 * Calling `setTargeting` will **always** trigger the Decision Engine to recalculate all targeting decisions,
 * which triggers a re-render of all consumers. It is recommended that you wrap the invocation of `setTargeting`
 * within a `useEffect` and carefully consider how often 'setTargeting' is invoked.
 *
 * @returns {function} the Decision Engine's `setTargeting` function
 *
 * @example
 * export const ExampleComponent = ({ targetingValue }) => {
 *   const setTargeting = useTargeting();
 *   useEffect(() => {
 *     setTargeting({ targetingKey: targetingValue });
 *   }, [targetingValue, setTargeting]);
 *   return null;
 * };
 */
exports.useTargeting = () => {
    const { setTargeting } = use_engine_context_1.useEngineContext('useTargeting');
    return setTargeting;
};
//# sourceMappingURL=use-targeting.js.map